summaryrefslogtreecommitdiff
path: root/include/kernel/con.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/kernel/con.h')
-rw-r--r--include/kernel/con.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/include/kernel/con.h b/include/kernel/con.h
index 8777342..178a0d3 100644
--- a/include/kernel/con.h
+++ b/include/kernel/con.h
@@ -1,7 +1,7 @@
/*
* con.h
*
* Basic VGA text console. Implements printf() and puts().
*/
#ifndef _CON_H
@@ -11,7 +11,6 @@ void con_init(void);
void con_clear(void);
-int puts(char *s);
-int printf(char*, ...);
+int printk(char*, ...);
#endif
@@ -1,7 +1,7 @@
* con.h
*
- * Basic VGA text console. Implements printf() and puts().
+ * Basic VGA text console. Implements printk() and puts().
*/
#ifndef _CON_H